@@ -180,7 +180,8 @@ make.communal <- function(dat,
                      as.integer(ind.iv),
                      as.double(cuts),
                      as.integer(n.years),
-                     DUP = FALSE
+                     DUP = FALSE,
+                     PACKAGE = "eha",
                      )$yy
       yy <- matrix(yy, ncol = ncol(xx) + 1)
     }
